@@ -82,11 +82,11 @@ class QuadratureRule(object):
 
         .. math ::
 
-            [a, \infty] : t = \frac{1}{x} + (a-1)
+            \lbrack a, \infty \rbrack : t = \frac{1}{x} + (a-1)
 
-            [-\infty, b] : t = (b+1) - \frac{1}{x}
+            \lbrack -\infty, b \rbrack : t = (b+1) - \frac{1}{x}
 
-            [-\infty, \infty] : t = \frac{x}{\sqrt{1-x^2}}
+            \lbrack -\infty, \infty \rbrack : t = \frac{x}{\sqrt{1-x^2}}
 
         """
         ctx = self.ctx
@@ -420,7 +420,7 @@ class GaussLegendre(QuadratureRule):
         orig = ctx.prec
         ctx.prec = int(prec*1.5)
         if degree == 1:
-            x = ctx.mpf(3)/5
+            x = ctx.sqrt(ctx.mpf(3)/5)
             w = ctx.mpf(5)/9
             nodes = [(-x,w),(ctx.zero,ctx.mpf(8)/9),(x,w)]
             ctx.prec = orig
